@@ -6,7 +6,7 @@ possible values for each attributes.
 
 This file is part of PyVISA.
 
-:copyright: 2014-2020 by PyVISA Authors, see AUTHORS for more details.
+:copyright: 2014-2022 by PyVISA Authors, see AUTHORS for more details.
 :license: MIT, see LICENSE for more details.
 
 """
@@ -238,6 +238,38 @@ class EnumAttribute(Attribute):
         return value
 
 
+class FlagAttribute(Attribute):
+    """Class for attributes with Flag values that map to a PyVISA Enum."""
+
+    #: Enum type with valid values.
+    enum_type: ClassVar[Type[enum.IntFlag]]
+
+    @classmethod
+    def redoc(cls) -> None:
+        """Add the enum member to the docstring."""
+        super(FlagAttribute, cls).redoc()
+        cls.__doc__ += "\n:type: :class:%s.%s" % (
+            cls.enum_type.__module__,
+            cls.enum_type.__name__,
+        )
+
+    def post_get(self, value: Any) -> enum.IntFlag:
+        """Convert the VISA value to the proper enum member."""
+        return self.enum_type(value)
+
+    def pre_set(self, value: enum.IntFlag) -> Any:
+        """Validate the value passed against the enum."""
+        # Python 3.8 raise if a non-Enum is used for value
+        try:
+            value = self.enum_type(value)
+        except ValueError:
+            raise ValueError(
+                "%r is an invalid value for attribute %s, "
+                "should be a %r" % (value, self.visa_name, self.enum_type)
+            )
+        return value
+
+
 class IntAttribute(Attribute):
     """Class for attributes with integers values."""
 
@@ -605,7 +637,7 @@ class AttrVI_ATTR_TMO_VALUE(RangeAttribute):
 
     min_value, max_value, values = 0, 0xFFFFFFFF, None
 
-    def pre_set(self, value: Union[int, float]) -> int:
+    def pre_set(self, value: Optional[Union[int, float]]) -> int:
         """Convert the timeout to an integer recognized by the VISA library."""
         timeout = util.cleanup_timeout(value)
         return timeout
@@ -1612,7 +1644,7 @@ class AttrVI_ATTR_ASRL_STOP_BITS(EnumAttribute):
     enum_type = constants.StopBits
 
 
-class AttrVI_ATTR_ASRL_FLOW_CNTRL(EnumAttribute):
+class AttrVI_ATTR_ASRL_FLOW_CNTRL(FlagAttribute):
     """Indicate the type of flow control used by the transfer mechanism."""
 
     resources = [(constants.InterfaceType.asrl, "INSTR")]
@@ -1623,7 +1655,7 @@ class AttrVI_ATTR_ASRL_FLOW_CNTRL(EnumAttribute):
 
     visa_type = "ViUInt16"
 
-    default = constants.VI_ASRL_FLOW_NONE
+    default = constants.ControlFlow.none
 
     read, write, local = True, True, False
 
